Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrNoUsers = errors.New(lang.ErrNoUsersS) ErrWrongDBClaim = errors.New(lang.ErrWrongDBClaimS) )
Functions ¶
This section is empty.
Types ¶
type ClaimsMap ¶
func NewClaimsMap ¶
func NewClaimsMap() *ClaimsMap
type FbIf ¶
type FbIf interface {
Search(ctx context.Context, key, value string, cb func(uid string) error) error
StoreAuthClaims(ctx context.Context, uid string, newClaims map[string]any) error
IterUsers(cb func(*auth.UserRecord) error) error
GetUsers(ctx context.Context, uids []auth.UserIdentifier) (*auth.GetUsersResult, error)
GetSpecs(ctx context.Context) (map[string]any, error)
UpdateSpecs(tr *firestore.Transaction, updates map[string]any) error
RunTransaction(ctx context.Context, cb func(tr *firestore.Transaction, privileged map[string]any) error) error
DoList() error
}
FbIf is an interface to be able to mock Firebase functionality
type FeIf ¶
type FeIf interface {
Run()
CurrentPage() string
SetPage(string)
SetOnShow(string, func())
ShowMsg(ms ...string)
ShowConfirm(onYes, onNo func(), ms ...string)
ShowProgress(ctx context.Context, cancelFunc context.CancelFunc, ms ...string)
ClaimButtonSetDisabled(index int, isDisabled bool)
HidePopup(popup string)
LayoutUsers()
Quit()
ShowClaimChoser(i int, key string, c Claim)
CreateClaimChoser()
ClaimsDateSetDisabled(bool)
ClaimsBtns(bool)
ClaimsSetDate(time.Time)
ClaimsDate() *time.Time
ReplaceTableItem(i int, key string, p tview.Primitive)
}
FeIf is an interface to be able to mock tview GUI functionality.
Click to show internal directories.
Click to hide internal directories.